import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import * as RulesAPI from "./rules.js";
import { SinglePage } from "../../pagination.js";
export declare class Rules extends APIResource {
    /**
     * Put Rules
     */
    update(params: RuleUpdateParams, options?: Core.RequestOptions): Core.APIPromise<RuleUpdateResponse>;
    /**
     * Rules
     */
    list(params: RuleListParams, options?: Core.RequestOptions): Core.PagePromise<RuleListResponsesSinglePage, RuleListResponse>;
}
export declare class RuleListResponsesSinglePage extends SinglePage<RuleListResponse> {
}
/**
 * List of Cloud Connector rules
 */
export type RuleUpdateResponse = Array<RuleUpdateResponse.RuleUpdateResponseItem>;
export declare namespace RuleUpdateResponse {
    interface RuleUpdateResponseItem {
        id?: string;
        description?: string;
        enabled?: boolean;
        expression?: string;
        /**
         * Parameters of Cloud Connector Rule
         */
        parameters?: RuleUpdateResponseItem.Parameters;
        /**
         * Cloud Provider type
         */
        provider?: 'aws_s3' | 'r2' | 'gcp_storage' | 'azure_storage';
    }
    namespace RuleUpdateResponseItem {
        /**
         * Parameters of Cloud Connector Rule
         */
        interface Parameters {
            /**
             * Host to perform Cloud Connection to
             */
            host?: string;
        }
    }
}
export interface RuleListResponse {
    id?: string;
    description?: string;
    enabled?: boolean;
    expression?: string;
    /**
     * Parameters of Cloud Connector Rule
     */
    parameters?: RuleListResponse.Parameters;
    /**
     * Cloud Provider type
     */
    provider?: 'aws_s3' | 'r2' | 'gcp_storage' | 'azure_storage';
}
export declare namespace RuleListResponse {
    /**
     * Parameters of Cloud Connector Rule
     */
    interface Parameters {
        /**
         * Host to perform Cloud Connection to
         */
        host?: string;
    }
}
export interface RuleUpdateParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: List of Cloud Connector rules
     */
    body: Array<RuleUpdateParams.Body>;
}
export declare namespace RuleUpdateParams {
    interface Body {
        id?: string;
        description?: string;
        enabled?: boolean;
        expression?: string;
        /**
         * Parameters of Cloud Connector Rule
         */
        parameters?: Body.Parameters;
        /**
         * Cloud Provider type
         */
        provider?: 'aws_s3' | 'r2' | 'gcp_storage' | 'azure_storage';
    }
    namespace Body {
        /**
         * Parameters of Cloud Connector Rule
         */
        interface Parameters {
            /**
             * Host to perform Cloud Connection to
             */
            host?: string;
        }
    }
}
export interface RuleListParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace Rules {
    export import RuleUpdateResponse = RulesAPI.RuleUpdateResponse;
    export import RuleListResponse = RulesAPI.RuleListResponse;
    export import RuleListResponsesSinglePage = RulesAPI.RuleListResponsesSinglePage;
    export import RuleUpdateParams = RulesAPI.RuleUpdateParams;
    export import RuleListParams = RulesAPI.RuleListParams;
}
//# sourceMappingURL=rules.d.ts.map