import { APIResource } from "../../../resource.js";
import * as Core from "../../../core.js";
import * as AIAPI from "./ai.js";
import * as ModelsAPI from "./models/models.js";
export declare class AI extends APIResource {
    models: ModelsAPI.Models;
    /**
     * This endpoint provides users with the capability to run specific AI models
     * on-demand.
     *
     * By submitting the required input data, users can receive real-time predictions
     * or results generated by the chosen AI model. The endpoint supports various AI
     * model types, ensuring flexibility and adaptability for diverse use cases.
     *
     * Model specific inputs available in
     * [Cloudflare Docs](https://developers.cloudflare.com/workers-ai/models/).
     */
    run(modelName: string, params: AIRunParams, options?: Core.RequestOptions): Core.APIPromise<AIRunResponse>;
}
export type AIRunResponse = Array<AIRunResponse.TextClassification> | Core.Uploadable | AIRunResponse.TextEmbeddings | AIRunResponse.AutomaticSpeechRecognition | Array<AIRunResponse.ImageClassification> | Array<AIRunResponse.ObjectDetection> | AIRunResponse.UnionMember6 | Core.Uploadable | AIRunResponse.Translation | AIRunResponse.Summarization | AIRunResponse.ImageToText;
export declare namespace AIRunResponse {
    interface TextClassification {
        label?: string;
        score?: number;
    }
    interface TextEmbeddings {
        data?: Array<Array<number>>;
        shape?: Array<number>;
    }
    interface AutomaticSpeechRecognition {
        text: string;
        vtt?: string;
        word_count?: number;
        words?: Array<AutomaticSpeechRecognition.Word>;
    }
    namespace AutomaticSpeechRecognition {
        interface Word {
            end?: number;
            start?: number;
            word?: string;
        }
    }
    interface ImageClassification {
        label?: string;
        score?: number;
    }
    interface ObjectDetection {
        box?: ObjectDetection.Box;
        label?: string;
        score?: number;
    }
    namespace ObjectDetection {
        interface Box {
            xmax?: number;
            xmin?: number;
            ymax?: number;
            ymin?: number;
        }
    }
    interface UnionMember6 {
        response?: string;
        tool_calls?: Array<UnionMember6.ToolCall>;
    }
    namespace UnionMember6 {
        interface ToolCall {
            arguments?: unknown;
            name?: string;
        }
    }
    interface Translation {
        translated_text?: string;
    }
    interface Summarization {
        summary?: string;
    }
    interface ImageToText {
        description?: string;
    }
}
export type AIRunParams = AIRunParams.TextClassification | AIRunParams.TextToImage | AIRunParams.TextEmbeddings | AIRunParams.AutomaticSpeechRecognition | AIRunParams.ImageClassification | AIRunParams.ObjectDetection | AIRunParams.Variant6 | AIRunParams.Variant7 | AIRunParams.Translation | AIRunParams.Summarization | AIRunParams.ImageToText;
export declare namespace AIRunParams {
    interface TextClassification {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        text: string;
    }
    interface TextToImage {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        prompt: string;
        /**
         * Body param:
         */
        guidance?: number;
        /**
         * Body param:
         */
        height?: number;
        /**
         * Body param:
         */
        image?: Array<number>;
        /**
         * Body param:
         */
        image_b64?: string;
        /**
         * Body param:
         */
        lora_weights?: Array<number>;
        /**
         * Body param:
         */
        loras?: Array<string>;
        /**
         * Body param:
         */
        mask?: Array<number>;
        /**
         * Body param:
         */
        negative_prompt?: string;
        /**
         * Body param:
         */
        num_steps?: number;
        /**
         * Body param:
         */
        seed?: number;
        /**
         * Body param:
         */
        strength?: number;
        /**
         * Body param:
         */
        width?: number;
    }
    interface TextEmbeddings {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        text: string | Array<string>;
    }
    interface AutomaticSpeechRecognition {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        audio: Array<number>;
    }
    interface ImageClassification {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        image: Array<number>;
    }
    interface ObjectDetection {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        image?: Array<number>;
    }
    interface Variant6 {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        prompt: string;
        /**
         * Body param:
         */
        frequency_penalty?: number;
        /**
         * Body param:
         */
        lora?: string;
        /**
         * Body param:
         */
        max_tokens?: number;
        /**
         * Body param:
         */
        presence_penalty?: number;
        /**
         * Body param:
         */
        raw?: boolean;
        /**
         * Body param:
         */
        repetition_penalty?: number;
        /**
         * Body param:
         */
        seed?: number;
        /**
         * Body param:
         */
        stream?: boolean;
        /**
         * Body param:
         */
        temperature?: number;
        /**
         * Body param:
         */
        top_k?: number;
        /**
         * Body param:
         */
        top_p?: number;
    }
    interface Variant7 {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        messages: Array<AIRunParams.Variant7.Message>;
        /**
         * Body param:
         */
        frequency_penalty?: number;
        /**
         * Body param:
         */
        max_tokens?: number;
        /**
         * Body param:
         */
        presence_penalty?: number;
        /**
         * Body param:
         */
        repetition_penalty?: number;
        /**
         * Body param:
         */
        seed?: number;
        /**
         * Body param:
         */
        stream?: boolean;
        /**
         * Body param:
         */
        temperature?: number;
        /**
         * Body param:
         */
        tools?: Array<AIRunParams.Variant7.Tool>;
        /**
         * Body param:
         */
        top_k?: number;
        /**
         * Body param:
         */
        top_p?: number;
    }
    namespace Variant7 {
        interface Message {
            content: string;
            role: string;
        }
        interface Tool {
            function?: Tool.Function;
            type?: string;
        }
        namespace Tool {
            interface Function {
                description?: string;
                name?: string;
                parameters?: Function.Parameters;
            }
            namespace Function {
                interface Parameters {
                    properties?: Record<string, Parameters.Properties>;
                    required?: Array<string>;
                    type?: string;
                }
                namespace Parameters {
                    interface Properties {
                        description?: string;
                        type?: string;
                    }
                }
            }
        }
    }
    interface Translation {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        target_lang: string;
        /**
         * Body param:
         */
        text: string;
        /**
         * Body param:
         */
        source_lang?: string;
    }
    interface Summarization {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        input_text: string;
        /**
         * Body param:
         */
        max_length?: number;
    }
    interface ImageToText {
        /**
         * Path param:
         */
        account_id: string;
        /**
         * Body param:
         */
        image: Array<number>;
        /**
         * Body param:
         */
        max_tokens?: number;
        /**
         * Body param:
         */
        messages?: Array<AIRunParams.ImageToText.Message>;
        /**
         * Body param:
         */
        prompt?: string;
        /**
         * Body param:
         */
        raw?: boolean;
        /**
         * Body param:
         */
        temperature?: number;
    }
    namespace ImageToText {
        interface Message {
            content: string;
            role: string;
        }
    }
}
export declare namespace AI {
    export import AIRunResponse = AIAPI.AIRunResponse;
    export import AIRunParams = AIAPI.AIRunParams;
    export import Models = ModelsAPI.Models;
}
//# sourceMappingURL=ai.d.ts.map